// MainDlg.cpp : implementation of the CMainDlg class
//
/////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "resource.h"

#include "aboutdlg.h"
#include "MainDlg.h"

BOOL CMainDlg::PreTranslateMessage(MSG* pMsg)
{
	return CWindow::IsDialogMessage(pMsg);
}

LRESULT CMainDlg::OnInitDialog(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
{
	//---get list of WLAN
	if(!m_wlan.open()){
		MessageBox(CString(MAKEINTRESOURCE(IDS_ERROR_INTERFACE)),CString(MAKEINTRESOURCE(IDR_MAINFRAME)),MB_OK|MB_ICONERROR);
		CloseDialog(-1);
		return -1;
	}
	if(!m_wlan.readGUID()){
		MessageBox(CString(MAKEINTRESOURCE(IDS_ERROR_INTERFACE)),CString(MAKEINTRESOURCE(IDR_MAINFRAME)),MB_OK|MB_ICONERROR);
		CloseDialog(-1);
		return -1;
	}
	if(!m_wlan.readProfiles()){
		MessageBox(CString(MAKEINTRESOURCE(IDS_ERROR_PROFILE)),CString(MAKEINTRESOURCE(IDR_MAINFRAME)),MB_OK|MB_ICONERROR);
		CloseDialog(-1);
		return -1;
	}

	// center the dialog on the screen
	CenterWindow();

	// set icons
	HICON hIcon = (HICON)::LoadImage(_Module.GetResourceInstance(), MAKEINTRESOURCE(IDR_MAINFRAME), 
		IMAGE_ICON, ::GetSystemMetrics(SM_CXICON), ::GetSystemMetrics(SM_CYICON), LR_DEFAULTCOLOR);
	SetIcon(hIcon, TRUE);
	HICON hIconSmall = (HICON)::LoadImage(_Module.GetResourceInstance(), MAKEINTRESOURCE(IDR_MAINFRAME), 
		IMAGE_ICON, ::GetSystemMetrics(SM_CXSMICON), ::GetSystemMetrics(SM_CYSMICON), LR_DEFAULTCOLOR);
	SetIcon(hIconSmall, FALSE);

	// register object for message filtering
	CMessageLoop* pLoop = _Module.GetMessageLoop();
	ATLASSERT(pLoop != NULL);
	pLoop->AddMessageFilter(this);
	pLoop->AddIdleHandler(this);
	UIAddChildWindowContainer(m_hWnd);

	//disable "Connect" button
	UIEnable(IDOK,FALSE);

	//---init list view
	InitListView();

	return TRUE;
}

void CMainDlg::InitListView()
{
	m_ListView=GetDlgItem(IDC_LIST_AP);

	//---insert column
	CRect rect;
	m_ListView.GetClientRect(rect);
	m_ListView.InsertColumn(0, CString(MAKEINTRESOURCE(IDS_COLUMN_PROFILE)),LVCFMT_LEFT,rect.Width());
	m_ListView.SetExtendedListViewStyle(m_ListView.GetExtendedListViewStyle() | LVS_EX_FULLROWSELECT | LVS_EX_GRIDLINES);

	//---set number of profiles
	UINT numProfiles=m_wlan.numProfiles();
	m_ListView.SetItemCount(numProfiles);
	if(numProfiles){
		//---set first item selected
		m_ListView.SetFocus();
		m_ListView.SetItemState(0,LVNI_SELECTED | LVNI_FOCUSED,LVNI_SELECTED | LVNI_FOCUSED);
	}
}


//get list of access points
LRESULT CMainDlg::OnGetDispInfoListAP(int /*idCtrl*/, LPNMHDR pNMHDR, BOOL& /*bHandled*/)
{
	NMLVDISPINFO *pDispInfo = reinterpret_cast<NMLVDISPINFO*>(pNMHDR);

	int iItem=pDispInfo->item.iItem;
	if(!(pDispInfo->item.mask & LVIF_TEXT))return FALSE;

	_tcsncpy(pDispInfo->item.pszText, m_wlan.getProfile(iItem).strProfileName,pDispInfo->item.cchTextMax);

	return TRUE;
}

//double click on item
LRESULT CMainDlg::OnListAPAction(int /*idCtrl*/, LPNMHDR pNMHDR, BOOL& /*bHandled*/)
{
	if(ConnectSelected()){
		//connection started : close dialog
		CloseDialog(IDOK);
	}
	return TRUE;
}

//connect to selected item
bool CMainDlg::ConnectSelected()
{
	//get selected item
	int iItem=m_ListView.GetNextItem(-1,LVNI_ALL|LVNI_SELECTED);

	//connect
	if(iItem!=-1){
		m_wlan.connect(m_wlan.getProfile(iItem).strProfileName);
		return true;
	}else{
		return false;
	}
}

//Selection changed - activate and deactivate "Connect" button
LRESULT CMainDlg::OnItemChangedListAP(int /*idCtrl*/, LPNMHDR pNMHDR, BOOL& /*bHandled*/)
{
	NMLISTVIEW *pListView= reinterpret_cast<NMLISTVIEW*>(pNMHDR);

	UIEnable(IDOK,(pListView->iItem != -1));

	return 0;
}


LRESULT CMainDlg::OnOK(WORD /*wNotifyCode*/, WORD wID, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
{
	if(ConnectSelected()){
		//connection started : close dialog
		CloseDialog(IDOK);
	}
	return 0;
}

//disconnect
LRESULT CMainDlg::OnDisconnect(WORD /*wNotifyCode*/, WORD /*wID*/, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
{
	m_wlan.disconnect();

	return 0;
}

//---not so important : generated by wizard

LRESULT CMainDlg::OnDestroy(UINT /*uMsg*/, WPARAM /*wParam*/, LPARAM /*lParam*/, BOOL& /*bHandled*/)
{
	// unregister message filtering
	CMessageLoop* pLoop = _Module.GetMessageLoop();
	ATLASSERT(pLoop != NULL);
	pLoop->RemoveMessageFilter(this);
	pLoop->RemoveIdleHandler(this);

	return 0;
}

LRESULT CMainDlg::OnAppAbout(WORD /*wNotifyCode*/, WORD /*wID*/, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
{
	CAboutDlg dlg;
	dlg.DoModal();
	return 0;
}


LRESULT CMainDlg::OnCancel(WORD /*wNotifyCode*/, WORD wID, HWND /*hWndCtl*/, BOOL& /*bHandled*/)
{
	CloseDialog(wID);
	return 0;
}

void CMainDlg::CloseDialog(int nVal)
{
	DestroyWindow();
	::PostQuitMessage(nVal);
}

